Gallery of Examples — Python documentation

# Gallery of Examples

Test examples.

sphx_glr_auto_examples_local_module.py

Error during scraping

Repr test

“SVG”:-graphics_

Command line arguments support

Logging test

Pickling

Testing future statements across examples

Matplotlib alt text

Animation support

Link to other packages

orphan

# Future examples

Examples that use `__future__`.

Test without __future__ imports

Test __future__ imports across cells

Gallery generated by Sphinx-Gallery